DiffEntry

Enum DiffEntry 

pub enum DiffEntry<Content> {
    LeftOnly {
        path: Path,
        entry_type: TreeEntryType,
        content: Content,
    },
    Both {
        path: Path,
        left_type: TreeEntryType,
        right_type: TreeEntryType,
        content: Content,
    },
    RightOnly {
        path: Path,
        entry_type: TreeEntryType,
        content: Content,
    },
}
Available on crate feature diff only.
Represents a diff of a single file

It is generic over the content of the file diff. For tree diffs, Content is a pair of ObjectIds, one of which may be zero. For full diffs, Content is a similar::TextDiff.

Variants



LeftOnly

Fields

path: Path
entry_type: TreeEntryType
content: Content


Both

Fields

path: Path
left_type: TreeEntryType
right_type: TreeEntryType
content: Content


RightOnly

Fields

path: Path
entry_type: TreeEntryType
content: Content

Implementations

Source

impl<Content> DiffEntry<Content>

pub fn content(&self) -> &Content

The content of the diff entry

pub fn path(&self) -> &Path

The path of the file that the entry represents

pub fn map_content<T>(&self, fun: impl Fn(&Content) -> T) -> DiffEntry<T>

Map a function over the content contained in the entry.

pub fn map_content_res<T, E>( &self, fun: impl Fn(&Content) -> Result<T, E>, ) -> Result<DiffEntry<T>, E>

Map a fallible function over the content contained in the entry.

Source

impl DiffEntry<(ObjectId, ObjectId)>

pub async fn resolve<F: FileSystem>( &self, repo: &Repo<F>, config: TextDiffConfig, ) -> GResult<DiffEntry<TextDiff<'static, 'static, [u8]>>>

Look up the objects encoded in the diff entry and compute a diff of the files.