pub enum FileSystemError {
NotFound(Box<dyn Any>),
Other(Box<dyn Any>),
}Expand description
An error encountered when doing file or directory operations.
Rather than make everything generic over the type of errors, we use
Box<dyn Any> to hold platform-native errors.
Variants