Module object

Module object 

A module for working with git objects

This module contains data types for all git objects. Objects are acquired from a Repo by looking them up using their ObjectId, or from one of the lookup_* family of methods on existing objects.

Structs

Blob
A blob object
Commit
A commit object
ObjectHeader
An arbitrary object header, with a name and a value
ObjectHeaderIter
An iterator over additional headers in an object
ObjectId
The ID of a git object
ObjectSize
The size of a git object; a newtype wrapper around a u64
Tag
A tag object
Tree
A tree object
TreeEntry
An entry in a tree object
TreeEntryIter
An iterator over the entries in a tree object

Enums

Object
A git object
ObjectType
The type of a git object, as a plain (fieldless) enum
TreeEntryType
The type of an entry in a tree