pub enum TreeEntryType {
File,
Executable,
Symlink,
Tree,
Commit,
}Expand description
The type of an entry in a tree
Variants
File
A non-executable file pointing to a blob
Executable
An executable file pointing to a blob
Symlink
A symbolic link
Symbolic links in git are encoded as a tree entry of type symlink pointing to a blob. The blob’s content is the path of the symlink target.
Tree
A sub-tree, i.e. a subdirectory
Commit
A pointer to a commit
This is used for git submodules.