Commit

Struct Commit 

pub struct Commit { /* private fields */ }
A commit object

Implementations

Source

impl Commit

pub fn id(&self) -> ObjectId

The ObjectId of the commit

pub fn body(&self) -> &[u8]

The raw data in the object

pub fn tree(&self) -> ObjectId

The ObjectId of the tree that the commit points to

pub fn parents(&self) -> &[ObjectId]

The ObjectIds of all of the parents of the commit

pub fn author_date(&self) -> DateTime<FixedOffset>

The author date of the commit

pub fn commit_date(&self) -> DateTime<FixedOffset>

The commit date of the commit

Source

impl Commit

pub fn author_name(&self) -> &[u8]

The name of the commit author

pub fn author_email(&self) -> &[u8]

The email address of the commit author

pub fn committer_name(&self) -> &[u8]

The name of the committer

pub fn committer_email(&self) -> &[u8]

The email address of the committer

pub fn message(&self) -> &[u8]

The commit message

pub fn additional_headers(&self) -> ObjectHeaderIter<'_>

Get an iterator over any additional headers in the commit.

Additional headers are those not parsed by git-async, e.g. mergetag.

pub fn as_object(self) -> Object

Wrap the Commit as a generic Object.

pub async fn lookup_tree<F: FileSystem>(&self, repo: &Repo<F>) -> GResult<Tree>

Look up the tree that the commit points to, using the provided Repo.

pub async fn lookup_parents<F: FileSystem>( &self, repo: &Repo<F>, ) -> GResult<Vec<Commit>>

Look up all the parents of the commit, using the provided Repo.