pub struct Tag { /* private fields */ }Expand description
A tag object
Git tags can be ref tags or tag objects; this is the latter.
Implementations
Sourceimpl Tag
impl Tag
Sourcepub fn tag_type(&self) -> ObjectType
pub fn tag_type(&self) -> ObjectType
The type of the object pointed to by the tag
Sourcepub fn date(&self) -> Option<DateTime<FixedOffset>>
pub fn date(&self) -> Option<DateTime<FixedOffset>>
The tag date, if it exists
Sourceimpl Tag
impl Tag
Sourcepub fn tagger_name(&self) -> Option<&[u8]>
pub fn tagger_name(&self) -> Option<&[u8]>
The name of the tagger, if specified
Sourcepub fn tagger_email(&self) -> Option<&[u8]>
pub fn tagger_email(&self) -> Option<&[u8]>
The email address of the tagger, if specified
Sourcepub fn additional_headers(&self) -> ObjectHeaderIter<'_> ⓘ
pub fn additional_headers(&self) -> ObjectHeaderIter<'_> ⓘ
Get an iterator over any additional headers in the tag object.
Additional headers are those not parsed by git-async, e.g. mergetag.
Sourcepub async fn lookup_target<F: FileSystem>(
&self,
repo: &Repo<F>,
) -> GResult<Object>
pub async fn lookup_target<F: FileSystem>( &self, repo: &Repo<F>, ) -> GResult<Object>
Look up the target object of the tag using the provided Repo.