Module reference

Module reference 

A module for working with git refs

A git ref is a file which points to an object or to another ref.

To look up a ref, first construct a RefName and then use the Repo::lookup_ref method. A list of all refs in the repository can also be accessed using the Repo::ref_names method.

Structs

Ref
The contents of a git ref

Enums

RefName
The name of a git ref
RefTarget
The target of a git ref