Repo

Struct Repo 

pub struct Repo<F: FileSystem> { /* private fields */ }
A handle to a Git repository

It is generic over the implementation of filesystem operations.

Implementations

Source

impl<F: FileSystem> Repo<F>

pub async fn open(git_dir: F::Directory) -> GResult<Self>

Open the repository located at git_dir using a default RepoConfig.

pub async fn ref_names(&self) -> GResult<BTreeSet<RefName>>

Collect all the refs tracked by the repository

Includes HEAD, branches, tags, remotes and the stash

pub async fn head(&self) -> GResult<Ref>

Get the repository’s HEAD ref.

pub async fn lookup_ref(&self, name: &RefName) -> GResult<Ref>

Take a ref name and look up its content.

pub async fn lookup_object(&self, id: ObjectId) -> GResult<Object>

Look up a particular object in the repository, reading the entire object into memory.

pub async fn lookup_object_size_type( &self, id: ObjectId, ) -> GResult<(ObjectSize, ObjectType)>

Look up the size and type of an object, without reading it to memory or parsing its content.