pub struct WebDirectory { /* private fields */ }Available on crate feature
web only.Expand description
A provider for the Directory trait which delegates to web APIs
Implementations
Sourceimpl WebDirectory
impl WebDirectory
Sourcepub fn new(inner: &JsValue) -> Result<Self, JsError>
pub fn new(inner: &JsValue) -> Result<Self, JsError>
Construct a new WebDirectory from either a
web_sys::FileSystemDirectoryHandle or a web_sys::FileList.
If the argument is not one of these, this function returns an Err.