Structs
- Blob
- A blob object
- Commit
- A commit object
- Object
Header - An arbitrary object header, with a name and a value
- Object
Header Iter - An iterator over additional headers in an object
- Object
Id - The ID of a git object
- Object
Size - The size of a git object; a newtype wrapper around a
u64 - Tag
- A tag object
- Tree
- A tree object
- Tree
Entry - An entry in a tree object
- Tree
Entry Iter - An iterator over the entries in a tree object
Enums
- Object
- A git object
- Object
Type - The type of a git object, as a plain (fieldless) enum
- Tree
Entry Type - The type of an entry in a tree