pub struct Commit { /* private fields */ }Expand description
A commit object
Implementations
Sourceimpl Commit
impl Commit
The author date of the commit
Sourcepub fn commit_date(&self) -> DateTime<FixedOffset>
pub fn commit_date(&self) -> DateTime<FixedOffset>
The commit date of the commit
Sourceimpl Commit
impl Commit
The name of the commit author
The email address of the commit author
Sourcepub fn committer_name(&self) -> &[u8] ⓘ
pub fn committer_name(&self) -> &[u8] ⓘ
The name of the committer
Sourcepub fn committer_email(&self) -> &[u8] ⓘ
pub fn committer_email(&self) -> &[u8] ⓘ
The email address of the committer
Sourcepub fn additional_headers(&self) -> ObjectHeaderIter<'_> ⓘ
pub fn additional_headers(&self) -> ObjectHeaderIter<'_> ⓘ
Get an iterator over any additional headers in the commit.
Additional headers are those not parsed by git-async, e.g. mergetag.
Sourcepub async fn lookup_tree<F: FileSystem>(&self, repo: &Repo<F>) -> GResult<Tree>
pub async fn lookup_tree<F: FileSystem>(&self, repo: &Repo<F>) -> GResult<Tree>
Look up the tree that the commit points to, using the provided Repo.
Sourcepub async fn lookup_parents<F: FileSystem>(
&self,
repo: &Repo<F>,
) -> GResult<Vec<Commit>>
pub async fn lookup_parents<F: FileSystem>( &self, repo: &Repo<F>, ) -> GResult<Vec<Commit>>
Look up all the parents of the commit, using the provided Repo.